.. image:: https://img.shields.io/pypi/v/jaraco.office.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/jaraco.office.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/jaraco.office

.. image:: https://github.com/jaraco/jaraco.office/workflows/Automated%20Tests/badge.svg
   :target: https://github.com/jaraco/jaraco.office/actions?query=workflow%3A%22Automated+Tests%22
   :alt: Automated Tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. image:: https://readthedocs.org/projects/jaracooffice/badge/?version=latest
   :target: http://jaracooffice.readthedocs.io/en/latest/?badge=latest

``jaraco.office`` provides facilities for working with Microsoft Offic
applications (Word, Excel, etc) using the Win32 APIs. For cross-platform
libraries that work directly with Office 2007 OpenOffice formats, see
`ParadocX <https://github.com/yougov/paradocx>`_ and related packages.
